==> mgpcli-0.1.67.tar.gz: workflow/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'component/debug/debug_module.dart';
import 'component/device/device_manager.dart';
import 'component/home/application_install.dart';
import 'component/home/bottom_bar.dart';
import 'component/home/content_panel.dart';
import 'component/home/help_information.dart';
import 'component/home/sidebar.dart';
import 'component/info/baseinfo_page.dart';
import 'component/log/log_page.dart';
import 'component/log/log_utils.dart';
import 'component/release/release_main.dart';
import 'provider/shared_data_provider.dart';
import 'utils/net_util.dart';

void main() {
  NetUtils.init('127.0.0.1:8080');
  runApp(MultiProvider(
    providers: [
      ChangeNotifierProvider(create: (context) => SharedDataProvider())
    ],
    child: MyApp(),
  ));
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Workflow',
      theme: ThemeData(
        primarySwatch: Colors.deepPurple, // TODO 主题色待定
        hoverColor: Colors.deepPurpleAccent,
        dividerTheme: DividerThemeData().copyWith(thickness: 1),
      ),
      home: HomePage(title: 'Home'),
    );
  }
}

class HomePage extends StatefulWidget {
  HomePage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final _titles = ['连接设备', 'Attach&热重载', 'Release构建', '日志', '环境'];
  final _widgets = [
    DeviceManager(),
    DebugModule(null),
    ReleaseMain(),
    LogPage(),
    BaseInfoPage(),
  ];
  int currentIndex = 0;

  @override
  void initState() {
    super.initState();
    logManager.connectSocketClient();
    Provider.of<SharedDataProvider>(context, listen: false).update();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Row(
        children: <Widget>[
          Sidebar(
            menus: _titles,
            onTap: (index) => setState(() {
              currentIndex = index;
              // Logger.info('点击了${_titles[index]}');
            }),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                ApplicationInstall(),
                HelpInformation(),
              ],
            ),
          ),
          ContentPanel(
            title: _titles[currentIndex],
            builder: (context) => _widgets[currentIndex],
            hideBar: currentIndex == 3,
            darkTheme: true,
            bottomBar: BottomBar(),
          )
        ],
      ),
    );
  }
}

==> mgpcli-0.1.71.tar.gz: workflow/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:workflow/provider/log_state_provider.dart';

import 'component/debug/debug_module.dart';
import 'component/device/device_manager.dart';
import 'component/home/application_install.dart';
import 'component/home/bottom_bar.dart';
import 'component/home/content_panel.dart';
import 'component/home/help_information.dart';
import 'component/home/sidebar.dart';
import 'component/info/baseinfo_page.dart';
import 'component/log/log_page.dart';
import 'component/log/log_utils.dart';
import 'component/release/release_main.dart';
import 'provider/shared_data_provider.dart';
import 'utils/net_util.dart';

void main() {
  NetUtils.init('127.0.0.1:8080');
  runApp(MultiProvider(
    providers: [
      ChangeNotifierProvider(create: (context) => SharedDataProvider()),
      ChangeNotifierProvider(create: (context) => LogStateProvider()),
    ],
    child: MyApp(),
  ));
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Workflow',
      theme: ThemeData(
        primarySwatch: Colors.deepPurple, // TODO 主题色待定
        hoverColor: Colors.deepPurpleAccent,
        dividerTheme: DividerThemeData().copyWith(thickness: 1),
      ),
      home: HomePage(title: 'Home'),
    );
  }
}

class HomePage extends StatefulWidget {
  HomePage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final _titles = ['连接设备', 'Attach&热重载', 'Release构建', '日志', '环境'];
  final _widgets = [
    DeviceManager(),
    DebugModule(null),
    ReleaseMain(),
    LogPage(),
    BaseInfoPage(),
  ];
  int currentIndex = 0;

  @override
  void initState() {
    super.initState();
    logManager.connectSocketClient();
    Provider.of<SharedDataProvider>(context, listen: false).update();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Row(
        children: <Widget>[
          Sidebar(
            menus: _titles,
            onTap: (index) => setState(() {
              currentIndex = index;
              // Logger.info('点击了${_titles[index]}');
            }),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                ApplicationInstall(),
                HelpInformation(),
              ],
            ),
          ),
          ContentPanel(
            title: _titles[currentIndex],
            builder: (context) => _widgets[currentIndex],
            hideBar: currentIndex == 3,
            darkTheme: true,
            bottomBar: BottomBar(),
          )
        ],
      ),
    );
  }
}
